package cn.newfeifan.mall.module.distri.service.dailybill;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.newfeifan.mall.module.distri.controller.admin.dailybill.vo.*;
import cn.newfeifan.mall.module.distri.dal.dataobject.dailybill.DailyBillDO;
import cn.newfeifan.mall.framework.common.pojo.PageResult;
import cn.newfeifan.mall.framework.common.util.object.BeanUtils;

import cn.newfeifan.mall.module.distri.dal.mysql.dailybill.DailyBillMapper;

import static cn.newfeifan.mall.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.newfeifan.mall.module.distri.enums.ErrorCodeConstants.*;

/**
 * 每日账单 Service 实现类
 *
 * @author 非繁人
 */
@Service
@Validated
public class DailyBillServiceImpl implements DailyBillService {

    @Resource
    private DailyBillMapper dailyBillMapper;

    @Override
    public Long createDailyBill(DailyBillSaveReqVO createReqVO) {
        // 插入
        DailyBillDO dailyBill = BeanUtils.toBean(createReqVO, DailyBillDO.class);
        dailyBillMapper.insert(dailyBill);
        // 返回
        return dailyBill.getId();
    }

    @Override
    public void updateDailyBill(DailyBillSaveReqVO updateReqVO) {
        // 校验存在
        validateDailyBillExists(updateReqVO.getId());
        // 更新
        DailyBillDO updateObj = BeanUtils.toBean(updateReqVO, DailyBillDO.class);
        dailyBillMapper.updateById(updateObj);
    }

    @Override
    public void deleteDailyBill(Long id) {
        // 校验存在
        validateDailyBillExists(id);
        // 删除
        dailyBillMapper.deleteById(id);
    }

    private void validateDailyBillExists(Long id) {
        if (dailyBillMapper.selectById(id) == null) {
            throw exception(DAILY_BILL_NOT_EXISTS);
        }
    }

    @Override
    public DailyBillDO getDailyBill(Long id) {
        return dailyBillMapper.selectById(id);
    }

    @Override
    public PageResult<DailyBillDO> getDailyBillPage(DailyBillPageReqVO pageReqVO) {
        return dailyBillMapper.selectPage(pageReqVO);
    }

    @Override
    public void caleDailyBill() {
    }

}